@@ -6,8 +6,8 @@
 ;; Keywords: extensions
 ;; URL: https://thanosapollo.org/projects/gnosis
 
-;; Package-Version: 20251108.939
-;; Package-Revision: 43b8ba93a717
+;; Package-Version: 20260114.454
+;; Package-Revision: 6bd8f4e5a843
 
 ;; Package-Requires: ((emacs "27.2") (emacsql "4.1.0") (compat "29.1.4.2") (transient "0.7.2") (org-gnosis "0.0.9"))
 
@@ -403,7 +403,7 @@ This will not be applied to sentences that start with double space."
   (cl-assert (listp clozes) nil "Adding clozes: Clozes need to be a list.")
   (let ((cloze-string (or cloze-string gnosis-cloze-string)))
     (with-temp-buffer
-      (insert (gnosis-center-string (gnosis-org-format-string str)))
+      (insert (gnosis-org-format-string str))
       (dolist (cloze clozes)
         (let* ((cloze-text (gnosis-utils-trim-quotes cloze))
                (replacement (concat
@@ -2413,13 +2413,15 @@ Return thema ids for themata that match QUERY."
         (add-to-list 'global-mode-string
                      '(:eval
                        (if (and gnosis-due-themata-total (> gnosis-due-themata-total 0))
-                           (format " G:%d" gnosis-due-themata-total)
+                           (propertize (format " [%d] " gnosis-due-themata-total) 'face 'warning
+                                       'gnosis-modeline t)
                          "")))
         (force-mode-line-update))
     (setq global-mode-string
           (seq-remove (lambda (item)
-                        (and (listp item) (eq (car item) :eval)
-                             (string-prefix-p " G:" (format "%s" (eval (cadr item))))))
+                        (and (listp item)
+                             (eq (car item) :eval)
+                             (get-text-property 0 'gnosis-modeline (format "%s" (eval (cadr item))))))
                       global-mode-string))
     (force-mode-line-update)))
 
